pitchtools.diatonic_pitch_name_to_diatonic_pitch_class_name
===========================================================

.. autofunction:: abjad.tools.pitchtools.diatonic_pitch_name_to_diatonic_pitch_class_name
